<?php

namespace apexl\Io\modules\display\callbacks;

use apexl\Io\modules\display\pages\blankPage;
use apexl\Io\modules\display\pages\genericPageLeftMenu;
use apexl\Io\modules\display\pages\noUIiframeFlow;
use apexl\Io\modules\display\services\Render;

class boot
{
    public static function display()
    {
        //only apply a default if it hasn't already been done.
        if (!Render::getPage("default")) {
            Render::registerDefault(genericPageLeftMenu::getInstance());
        }
        if (!Render::getPage("noUI")) {
            Render::registerPage("noUI", blankPage::getInstance());
        }
        if (!Render::getPage("noUIiframe")) {
            Render::registerPage("noUIiframe", noUIiframeFlow::getInstance());
        }
    }
}
