<?php

namespace apexl\Io\modules\display\components;

use apexl\Io\modules\component\entities\componentEntity;

/**
 * @type componentEntity
 * Class ThePageContent
 * @package apexl\Io\modules\display\components
 */
class ThePageContent extends componentEntity
{
    private static array $wrapperClasses = [
        'h-100'
    ];

    public function __toString()
    {
        $this->addProperty('pageContentClasses', self::$wrapperClasses,);
        return parent::__toString();
    }



    public static function addWrapperClass(string $class): void
    {
        self::$wrapperClasses[] = $class;
    }
}
